clojure.tools.deps

API namespace for tools.deps. New dep types are defined via the multimethods in c.t.deps.extensions. This namespace auto-loads the built-in extensions for :mvn, :git, :local, etc. Most functions for reading, validating, and manipulating deps.edn data have been deprecated and moved to clojure.tools.deps.edn library.

API namespace for tools.deps. New dep types are defined via the multimethods
in c.t.deps.extensions. This namespace auto-loads the built-in extensions for
:mvn, :git, :local, etc. Most functions for reading, validating, and manipulating
deps.edn data have been deprecated and moved to clojure.tools.deps.edn library.
raw docstring

clojure.tools.deps.tool

API for managing CLI tools. This code may eventually move out of tools.deps and into the CLI code base as it is specific to the CLI.

API for managing CLI tools. This code may eventually move out of tools.deps
and into the CLI code base as it is specific to the CLI.
raw docstring

clojure.tools.deps.tree

API for managing deps trace structures and extracting tree renderings from traces. Note that deps are actually a graph and trees usually show the library more than once, expanding only once.

API for managing deps trace structures and extracting tree renderings from
traces. Note that deps are actually a graph and trees usually show the library
more than once, expanding only once.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries