API for managing CLI tools. This code may eventually move out of tools.deps and into the CLI code base as it is specific to the CLI.
API for managing CLI tools. This code may eventually move out of tools.deps and into the CLI code base as it is specific to the CLI.
(install-tool lib coord as)Procure the lib+coord, install the tool to the user tools dir (with lib, coord)
Procure the lib+coord, install the tool to the user tools dir (with lib, coord)
(list-tools)Return seq of available tool names
Return seq of available tool names
(remove-tool tool)Removes tool installation, if it exists. Returns true if it exists and was deleted.
Removes tool installation, if it exists. Returns true if it exists and was deleted.
(resolve-tool tool)Resolve a tool by name, look up and return: {:lib lib :coord coord} Or nil if unknown.
Resolve a tool by name, look up and return:
{:lib lib
:coord coord}
Or nil if unknown.(usage tool)Resolve a tool and return it's usage data, which may be nil. Throws ex-info if tool is unknown.
Resolve a tool and return it's usage data, which may be nil. Throws ex-info if tool is unknown.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |